# gt-examcard-parser 

Parser for Philips ExamCards. 

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install gtagora-connector.

```bash
pip install gt-examcard-parser 
```


## Basic usage

```python
import examcard as ec

filename = 'MyStudy.ExamCard'
examcard = ec.parse(filename)
```

## License
[MIT](https://choosealicense.com/licenses/mit/)
